"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const Client_1 = require("./Client");
const CommandHandler_1 = require("./Command/CommandHandler");
const CommandInfo_1 = require("./Command/CommandInfo");
const Gateway_1 = require("./Gateway");
class CommandClient extends Client_1.default {
    constructor(config, commandDirectory) {
        super(config);
        this.commandDirectory = commandDirectory;
        this.commands = {};
        this.commandHandler = new CommandHandler_1.default(this);
        this.loadCommands(this.commandDirectory);
    }
    createGateway(url) {
        return new Gateway_1.default(this, url, true);
    }
    loadCommands(directory) {
        const files = fs.readdirSync(directory);
        if (!files) {
            throw new Error("No commands found");
        }
        for (const file of files) {
            if (path.extname(file) !== ".js" || file.indexOf("Abstract") >= 0) {
                continue;
            }
            const cls = require(`${directory}/${file}`).default;
            const command = new cls(this);
            const info = new CommandInfo_1.default(cls);
            this.commands[info.name] = { command, info };
        }
    }
}
exports.default = CommandClient;
//# sourceMappingURL=CommandClient.js.map